@@ -30,7 +30,7 @@ sub normalline
 
         $hash{hour}   = $1;
         $hash{saying} = $3;
-        ($hash{nick}  = $2) =~ s/^[@%\+]//o; # Remove prefix
+        ($hash{nick}  = $2) =~ s/^[@%\+~&]//o; # Remove prefix
 
         return \%hash;
     } else {
@@ -58,7 +58,7 @@ sub thirdline
         $hash{hour} = $1;
         $hash{min}  = $2;
         $hash{saying} = $3;
-        ($hash{nick} = $line[0]) =~ s/^[@%\+]//o; # Remove prefix
+        ($hash{nick} = $line[0]) =~ s/^[@%\+~&]//o; # Remove prefix
 
         if ($#line >= 4 && ($line[1].$line[2]) eq 'waskicked' && ($line[$#line] =~ /\)$/)) {
                 $hash{kicker} = $line[4];
@@ -78,6 +78,9 @@ sub thirdline
         } elsif ($#line == 4 && ($line[2].$line[3]) eq 'hasjoined') {
             $hash{newjoin} = $line[0];
 
+        } elsif ($line[0] eq 'Joins:') { # Alt+O -> IRC -> Options -> Short join/parts
+            $hash{newjoin} = $line[1];
+
         } elsif ($#line == 5 && ($line[2].$line[3]) eq 'nowknown') {
             $hash{newnick} = $line[5];
 
